import { resolveHTTPResponse } from "@trpc/server";
import { getPath, notFoundError } from "./utils";
export function createSolidAPIHandler(opts) {
    return async (args) => {
        const path = getPath(args);
        const request = args.request;
        if (path === null) {
            return notFoundError(opts);
        }
        const res = {
            headers: {},
        };
        const { status, headers, body } = await resolveHTTPResponse({
            router: opts.router,
            responseMeta: opts.responseMeta,
            req: {
                method: request.method,
                headers: request.headers,
                query: new URL(args.request.url).searchParams,
                body: await request.text(),
            },
            path,
            createContext: async () => await opts.createContext?.({
                req: args.request,
                res,
            }),
        });
        return new Response(body, {
            status,
            headers: (headers
                ? { ...res.headers, ...headers }
                : res.headers),
        });
    };
}
